#
# spec file for package xprop
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xprop
Version:        1.2.8
Release:        1.1
Summary:        Property displayer for X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xprop displays window and font properties of an X server.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xprop
%{_mandir}/man1/xprop.1%{?ext_man}

%changelog
* Thu Nov 14 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.8
  * This release contains the following change to the way icons are displayed
    in the terminal when COLORTERM=truecolor in the environment variables:
    The vast majority of monospaced fonts are roughly half as wide as they
    are tall; to account for this when displaying icons, `xprop` draws each
    pixel twice in the horizontal, which nicely evens out the proportions.
    This patch utilizes the Lower Half Block character (▄) to obtain the
    same result in a quarter of the space. By setting both a background and
    a foreground color, we can draw two pixels per character cell, thereby
    halving the apparent height of an icon rather than doubling its width.
* Sun Feb  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.7
  * This release fixes a failure to build with C23 compilers.
* Sun Dec  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.6
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * Mark help(), usage(), and grammar() with _X_NORETURN _X_COLD
  * Declare help() and print_help() as static
  * Rename "dpy" function arguments to "display" to avoid shadowing global
  * Resolve many gcc -Wsign-compare warnings
  * Variable scope reductions as suggested by cppcheck
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Fri Nov 20 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.5
  * Add missing `-help` function
  * Make output with unknown width terminal the same as old code
  * Free string list returned from XmbTextPropertyToTextList
  * Correct icon buffer width computation for truecolor terminals
  * Check return value from ioctl(TIOCGWINSZ)
  * Don't display icons if they would line-wrap.
  * Break down memory allocation logic and fix overallocating for UTF8.
  * Fix aspect ratio for icon display by using two characters per icon pixel.
  * Support true color output for icons if the terminal advertises it.
  * Fix formatting of back-to-back not shown icons.
* Sun Mar 10 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.4
  * Add missing braces around else clause in Read_Quoted()
  * Fix -Wsign-compare warning in dsimple.c
  * Fix typo in xprop.man
  * Update configure.ac bug URL for gitlab migration
  * Update README for gitlab migration
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.2.3
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * Free the thunks used by Show_Prop
  * Free the data returned by XListProperties()
  * Free the data returned by XGetWindowProperty()
  * Free the data returned by Format_Icons()
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Tue Aug 13 2013 zaitor@opensuse.org
- Update to version 1.2.2:
  + Mark usage() as noreturn, as suggested by gcc
  - Wmissing-noreturn.
  + Fix const conversion warnings from gcc.
  + Add unicode argument to Format_Len_String to reduce code
    duplication.
  + Replace strlen/malloc/memcpy set with strdup.
  + Mark FatalError() as taking printf-style arguments.
  + config: Add missing AC_CONFIG_SRCDIR.
  + Enable setting property of type UTF8_STRING.
  + Expand description in README a little.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.2.1:
  + Improves the man page.
  + Fixes issues found by static code analysis
  + Other cleanups to the code
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: New dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xprop from xorg-x11. Initial version: 1.2.0.
